==> gnome-db-0.2.10.tar.gz: gnome-db-0.2.10/lib/gnome-db-shortcut.h <==
/* GNOME DB library
 * Copyright (C) 1999 Rodrigo Moya
 *
 * This Library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This Library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this Library; see the file COPYING.LIB.  If not,
 * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#if !defined(__gnome_db_shortcut_h__)
#  define __gnome_db_shortcut_h__

#include <gtk/gtkvbox.h>
#include <libgnome/gnome-defs.h>

BEGIN_GNOME_DECLS

typedef struct _GnomeDbShortcut      GnomeDbShortcut;
typedef struct _GnomeDbShortcutClass GnomeDbShortcutClass;

#define GNOME_DB_TYPE_SHORTCUT            (gnome_db_shortcut_get_type())
#define GNOME_DB_SHORTCUT(obj)            GTK_CHECK_CAST(obj, GNOME_DB_TYPE_SHORTCUT, GnomeDbShortcut)
#define GNOME_DB_SHORTCUT_CLASS(klass)    GTK_CHECK_CLASS_CAST(klass, GNOME_DB_TYPE_SHORTCUT, GnomeDbShortcutClass)
#define GNOME_DB_IS_SHORTCUT(obj)         GTK_CHECK_TYPE(obj, GNOME_DB_TYPE_SHORTCUT)
#define GNOME_DB_IS_SHORTCUT_CLASS(klass) (GTK_CHECK_CLASS_TYPE((klass), GNOME_DB_TYPE_SHORTCUT))

struct _GnomeDbShortcut
{
  GtkVBox    vbox;

  /* private */
  GtkWidget* tb;
};

struct _GnomeDbShortcutClass
{
  GtkVBoxClass parent_class;
};

GtkType    gnome_db_shortcut_get_type (void);
GtkWidget* gnome_db_shortcut_new (void);
void       gnome_db_shortcut_append (GnomeDbShortcut *shortcut,
                                     const gchar *str,
                                     const gchar *tooltip,
                                     const gchar *icon_file,
                                     GtkSignalFunc select_func,
                                     gpointer user_data);
void       gnome_db_shortcut_remove (GnomeDbShortcut *shortcut, const gchar *str);

END_GNOME_DECLS

#endif

==> gnome-db_0.2.96.orig.tar.gz: gnome-db-0.2.96/lib/gnome-db-shortcut.h <==
/* GNOME DB library
 * Copyright (C) 1999 Rodrigo Moya
 *
 * This Library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This Library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this Library; see the file COPYING.LIB.  If not,
 * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#if !defined(__gnome_db_shortcut_h__)
#  define __gnome_db_shortcut_h__

#include <gtk/gtkvbox.h>
#include <libgnome/gnome-defs.h>

BEGIN_GNOME_DECLS

typedef struct _GnomeDbShortcut      GnomeDbShortcut;
typedef struct _GnomeDbShortcutClass GnomeDbShortcutClass;

#define GNOME_DB_TYPE_SHORTCUT            (gnome_db_shortcut_get_type())
#define GNOME_DB_SHORTCUT(obj)            GTK_CHECK_CAST(obj, GNOME_DB_TYPE_SHORTCUT, GnomeDbShortcut)
#define GNOME_DB_SHORTCUT_CLASS(klass)    GTK_CHECK_CLASS_CAST(klass, GNOME_DB_TYPE_SHORTCUT, GnomeDbShortcutClass)
#define GNOME_DB_IS_SHORTCUT(obj)         GTK_CHECK_TYPE(obj, GNOME_DB_TYPE_SHORTCUT)
#define GNOME_DB_IS_SHORTCUT_CLASS(klass) (GTK_CHECK_CLASS_TYPE((klass), GNOME_DB_TYPE_SHORTCUT))

struct _GnomeDbShortcut {
	GtkVBox    vbox;

	/* private */
	GtkWidget* tb;
};

struct _GnomeDbShortcutClass {
	GtkVBoxClass parent_class;
};

GtkType    gnome_db_shortcut_get_type (void);
GtkWidget* gnome_db_shortcut_new (void);
void       gnome_db_shortcut_append (GnomeDbShortcut *shortcut,
                                     const gchar *str,
                                     const gchar *tooltip,
                                     const gchar *icon_file,
                                     GtkSignalFunc select_func,
                                     gpointer user_data);
void       gnome_db_shortcut_remove (GnomeDbShortcut *shortcut, const gchar *str);

END_GNOME_DECLS

#endif
